#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5724-I04 (C) COPYRIGHT International Business Machines Corp., 1997,2006
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# ifix launcher
thisHostname=`hostname -s`
thisDir=`dirname "$0"`
errorsduringinstall=0

if [ ! "$2" ]
then
  if [  -f ./IZ01624.sh ]
 then
 echo "Ifix_IZ01624: WVS Ifix IZ01624 Installer command syntax: "
 echo " to install ifix  syntax: ifix_IZ01624 -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_IZ01624.sh -uninstall "
 echo " "
 exit -1
 fi
fi

if [ $# -eq 0 ]
then
 echo "Ifix_IZ01624: WVS Ifix IZ01624 Installer command syntax: "
 echo " to install ifix  syntax: ifix_IZ01624 -install "
 echo "  "
 echo " to uninstall ifix  syntax: ifix_IZ01624.sh -uninstall "
 echo " "
 exit -1
fi

if [ -f /usr/WebSphere/AppServer/bin/setupCmdLine.sh ]
then
  . /usr/WebSphere/AppServer/bin/setupCmdLine.sh
fi


if [ ! "$WAS_HOME" ] ; then
   echo "Ifix_IZ01624: Please run WebSphere Application Server's setupCmdLine.sh to setup"
   echo "         the WAS Command line environment"
  exit -1
fi

if [ ! "$WVS_ROOT" ] ; then
   echo "Ifix_IZ01624: Please configure WebSphere Voice Server wvs.setenv according"
   echo "         to the WVS InfoCenter "
  exit -1
fi


isInstallOption=false
isUnInstallOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-install" ] ; then
     isInstallOption=true
  else
     if [ "$option" = "-uninstall" ] ; then
        isUnInstallOption=true
     fi
  fi
done

if [ "$isInstallOption" = "true" ] ; then
  if [ -f $WVS_ROOT/ifix/IZ01624/ttsmcl.bak ] ; then
    echo "Ifix_IZ01624: Ifix IZ01624 is applied, please uninstall before trying to reinstall ifix"
    exit -1
  fi
fi

if [ "$isInstallOption" = "true" ] ; then
  # Check that the ifix files are found
  echo "Ifix_IZ01624: Checking for ifix files ..."
  if [ -f $thisDir/ttsmcl ] ; then
    if [ -f $thisDir/ttsmcl ] ; then
      echo "Ifix_IZ01624: Ifix files found.. proceeding to install ifix"
      mkdir -p $WVS_ROOT/ifix/IZ01624
      cp -p $thisDir/IZ01624.sh $WVS_ROOT/ifix/ifix_IZ01624.sh
      cp -p $thisDir/stopVoiceServer.jacl $WVS_ROOT/ifix/IZ01624/.
      cp -p $WVS_ROOT/IBM/ibmtts/bin/ttsmcl $WVS_ROOT/ifix/IZ01624/ttsmcl.bak


      echo "Ifix_IZ01624: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1 -quiet
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_IZ01624: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_IZ01624: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/IZ01624
         exit -1
      fi

      cp -fp $thisDir/ttsmcl $WVS_ROOT/IBM/ibmtts/bin/.
      chmod 755 $WVS_ROOT/IBM/ibmtts/bin/ttsmcl

      echo "Ifix_IZ01624: Starting WebSphere Application Server"

      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_IZ01624: Application Server started successful, proceeding to install ifix"
      else
         echo "Ifix_IZ01624: Application Server reported failure during starting. Ifix installation was not successful. Please uninstall"
         exit -1
      fi

      echo "Ifix_IZ01624: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $thisDir/stopVoiceServer.jacl $thisHostname
      errorsduringinstall=$?


      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_IZ01624: Ifix is now applied, please reboot the system"
      else
        echo "Ifix_IZ01624: Ifix installation was not successful. Please uninstall. "
      fi

    else
      echo "Ifix_IZ01624: Ifix files missing, please be sure this script is in same directory as the binary files"
    fi
  fi
  cp -fp $thisDir/IZ01624.log $WVS_ROOT/log/.
fi


if [ "$isUnInstallOption" = "true" ] ; then
 # Check that the ifix backup files are found
 echo "Ifix_IZ01624: Checking for ifix backup files ..."
  if [ -f $WVS_ROOT/ifix/IZ01624/ttsmcl.bak ] ; then
    if [ -f $WVS_ROOT/ifix/IZ01624/ttsmcl.bak ] ; then
      echo "Ifix_IZ01624: Ifix backup files found.. proceeding to un-install ifix"

      
      echo "Ifix_IZ01624: Stopping WebSphere Application Server"
      $WAS_HOME/bin/stopServer.sh server1
      echo $?
      if [ "$?" = "246" -o "$?" = "0" ] ; then
         echo "Ifix_IZ01624: Application Server stopped successful, proceeding to install ifix"
      else
         echo "Ifix_IZ01624: Application Server reported failure during stopping. Ifix installation will not continue"
         rm -rf $WVS_ROOT/ifix/IZ01624
         exit -1
      fi

      cp -fp $WVS_ROOT/ifix/IZ01624/ttsmcl.bak $WVS_ROOT/IBM/ibmtts/bin/ttsmcl
     
      echo "Ifix_IZ01624: Starting WebSphere Application Server"
      $WAS_HOME/bin/startServer.sh server1 -quiet
      if [ "$?" = "111" -o "$?" = "0" ] ; then
         echo "Ifix_IZ01624: Application Server started successful, proceeding to uninstall ifix"
      else
         echo "Ifix_IZ01624: Application Server reported failure during starting. Ifix uninstallation was not successful. Please contact support"
         exit -1
      fi
       
      echo "Ifix_IZ01624: Stopping  WebSphere Voice Server"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/ifix/IZ01624/stopVoiceServer.jacl $thisHostname
      errorsduringinstall=$?
          
      echo "Ifix_IZ01624: Updating WebSphere Voice Server J2EE Application"
      $WAS_HOME/bin/wsadmin.sh -f $WVS_ROOT/.package/installEar.jacl $WVS_ROOT/ear wvsapp WVS5.1-$thisHostname $thisHostname
      errorsduringinstall=$?
      
      if [ $errorsduringinstall = "0" ] ; then
        echo "Ifix_IZ01624: Ifix is now uninstalled, please reboot the system"
        echo "Ifix_IZ01624:  Please remove the $WVS_ROOT/ifix/IZ01624 directory before attempting a subsequent install of this ifix."
      else
        echo "Ifix_IZ01624: Ifix uninstallation was not successful. Please contact support. "
      fi
      
    else
      echo "Ifix_IZ01624: Ifix backup files missing, uninstall not performed"
    fi
  else
    echo "Ifix_IZ01624: Ifix backup files missing, uninstall not performed"
  fi
fi
exit $?